/*
 * Copyright (C) 2003 Flameeyes <dgp85@users.sourceforge.net>
 */

#include "kbioritmi.h"
#include "qbioritmi.h"

#include "appletconfig.h"
#include "coupler.h"
#include "bioritmo.h"

#include <qpicture.h>
#include <qpainter.h>
#include <qlineedit.h>
#include <qlabel.h>
#include <qdatetime.h>
#include <qfile.h>
#include <qtextstream.h>

#include <kglobal.h>
#include <kconfig.h>
#include <kdatewidget.h>
#include <kdatepicker.h>
#include <kaboutapplication.h>
#include <kfiledialog.h>

KBioritmi::KBioritmi()
    : uiMainForm( 0, "KBioritmi" )
{
	centraldate->setDate( QDate::currentDate() );
	KGlobal::config()->setGroup("dates");
		QDateTime dt( QDate(1985, 11, 28) );
		birthdate->setDate( KGlobal::config()->readDateTimeEntry("birthdate", &dt).date() );

	biolabel->paintBioritmi( birthdate->date(), centraldate->date() );
	
	Coupler = 0;
}

KBioritmi::~KBioritmi()
{
}

void KBioritmi::dateChanged()
{
	biolabel->paintBioritmi( birthdate->date(), centraldate->date() );
}

void KBioritmi::configure()
{
	appletconfig *configDialog = new appletconfig(this);
	if ( configDialog->exec() )
	{
		birthdate->setDate( configDialog->birthdate->date() );
		biolabel->paintBioritmi( birthdate->date(), centraldate->date() );
	}
	
	delete configDialog;
}

void KBioritmi::about()
{
	KAboutApplication *about = new KAboutApplication(this);
	about->exec();
	delete about;
}

void KBioritmi::showCoupler()
{
	if ( !Coupler ) Coupler = new coupler(this);
	Coupler->show();
}

void KBioritmi::exportCSV()
{
	QString filename = KFileDialog::getSaveFileName(QString::null, "*.csv", this, "Select output filename");
	if ( filename.isNull() )
		return;
	
	QFile f(filename);
	f.open(IO_WriteOnly);
	
	QTextStream outfile(&f);
	
	outfile << "Date;Emotional;Phisical;Intellectual" << endl;
	
	bioritmo bio;
	bio.set_bir_date(birthdate->date());

	QDate d = centraldate->date().addDays(-14);
	for(int i = 0; i < 30; i++)
	{
		bio.set_bio_date(d);
		
		outfile << d.toString(Qt::ISODate) << ";"
			<< bio.cEmotivo() << ";"
			<< bio.cFisico() << ";"
			<< bio.cIntellettuale() << endl;
		
		d = d.addDays(1);
	}
	
	f.close();
}

#include "kbioritmi.moc"
